<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>OutputJACKFactory</name>
    <message>
        <location filename="../outputjackfactory.cpp" line="30"/>
        <source>JACK Plugin</source>
        <translation>JACK Module</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="53"/>
        <source>About Jack Output Plugin</source>
        <translation>Over de Jack Output Module</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="54"/>
        <source>Qmmp Jack Output Plugin</source>
        <translation>JACK Output Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="55"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Auteur: Yuriy Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
    </message>
</context>
</TS>
